@@ -1,3 +1,8 @@
+import sys
+if not hasattr(sys, 'frozen'):
+    import wxversion
+    wxversion.ensureMinimal('2.8')
+
 import wx
 from numpy import exp, random, arange, outer
 from wxmplot import ImageFrame
@@ -8,7 +13,7 @@ def gauss2d(x, y, x0, y0, sx, sy):
 
 if __name__ == '__main__':
     app = wx.App()
-    frame = ImageFrame(config_on_frame=True)
+    frame = ImageFrame()
     ny, nx = 350, 400
     x = arange(nx)
     y = arange(ny)
