@@ -1,3 +1,8 @@
+import sys
+if not hasattr(sys, 'frozen'):
+    import wxversion
+    wxversion.ensureMinimal('2.8')
+
 import wx
 from numpy import exp, random, arange, outer
 from wxmplot import ImageFrame
@@ -22,7 +27,7 @@ dat = 0.2 + (0.3*random.random(size=nx*ny).reshape(ny, nx) +
 
 
 app = wx.App()
-frame = ImageFrame(config_on_frame=True)
+frame = ImageFrame(mode='intensity')
 frame.display(dat, x=ox, y=oy)
 frame.Show()
 app.MainLoop()
