@@ -1,5 +1,9 @@
 #
 # read Pilatus image into numpy array
+import sys
+if not hasattr(sys, 'frozen'):
+    import wxversion
+    wxversion.ensureMinimal('2.8')
 
 import wx
 import Image
@@ -7,11 +11,9 @@ import numpy
 from wxmplot import ImageFrame
 
 def getPilatusImage(filename):
-    img = Image.open(filename)
-    dat = numpy.array(img.getdata()).reshape((195,487))
-    return img, dat
+    return numpy.array(Image.open(filename))
 
-img, dat = getPilatusImage('Pilatus.tiff')
+dat = getPilatusImage('Pilatus.tiff')
 
 app = wx.App()
 frame = ImageFrame()
