@@ -1,7 +1,13 @@
 #!/usr/bin/python
 #
 # simple example of MPlot
-
+import sys
+if not hasattr(sys, 'frozen'):
+    try:
+        import wxversion
+        wxversion.ensureMinimal('2.8')
+    except:
+        pass
 import wx
 import numpy
 import wxmplot
