@@ -1,13 +1,13 @@
 #!/usr/bin/env python
 #
 # Name:      wxmplot
-# Version:   0.9.10
+# Version:   0.9.14
 # Purpose:   Provide user-configurable 2D plotting module, using wxPython
 #            and matplotlib.
 # Author:    Matthew Newville
-# Copyright: Matthew Newville, The University of Chicago, 2012
+# Copyright: Matthew Newville, The University of Chicago, 2013
 # Licence:   BSD license
-# Updated:   05/22/2012
+# Updated:   2013/11/23
 #-----------------------------------------------------------------------------
 
 """
@@ -38,8 +38,8 @@ Principle objects:
   contains PlotPanel, dropdown menus from Save, Configure, Help, and so on,
   and a statusbar for messages and display of X,Y coordinates.
 
-WXMPlot.PlotPanel and PlotFrame plot data in 1D Numeric (or numarray) arrays,
-and provides these basic methods:
+WXMPlot.PlotPanel and PlotFrame plot data in 1D Numpy arrays, and provides
+these basic methods:
    plot(x,y):  start a new plot, and plot data x,y
       optional arguments (all keyword/value types):
           color='Blue'    for any X11 color name, (rgb) tuple, or '#RRGGBB'
@@ -64,12 +64,23 @@ and provides these basic methods:
    save_figure():  bring up file dialog for saving image of figure
 """
 
-__version__  = '0.9.10'
-__date__     = '2-Sept-2012'
+__version__  = '0.9.14'
+__date__     = '2013-Nov-23'
 
-from plotframe import PlotFrame
-from plotpanel import PlotPanel
-from imagepanel import ImagePanel
-from imageframe import ImageFrame
-from multiframe import MultiPlotFrame
-from plotapp  import PlotApp
+import sys
+try:
+    if not hasattr(sys, 'frozen'):
+        import wxversion
+        wxversion.ensureMinimal('2.8')
+except ImportError:
+    pass
+except: # probably a useless exception from ensureMinimal() about wx already being Imported.
+    pass
+
+from .baseframe import BaseFrame
+from .plotframe import PlotFrame
+from .plotpanel import PlotPanel
+from .imagepanel import ImagePanel
+from .imageframe import ImageFrame
+from .multiframe import MultiPlotFrame
+from .plotapp  import PlotApp
