@@ -5,6 +5,7 @@
 import wx
 import wx.lib.colourselect  as csel
 import wx.lib.agw.flatnotebook as flat_nb
+
 import wx.lib.scrolledpanel as scrolled
 import numpy as np
 
@@ -12,13 +13,12 @@ import matplotlib
 from matplotlib import rcParams
 from matplotlib.colors import colorConverter
 from matplotlib.font_manager import fontManager, FontProperties
-from matplotlib.pyparsing import ParseFatalException
 from matplotlib.colors import colorConverter
 to_rgba = colorConverter.to_rgba
 
-from utils import Closure, LabelEntry
-from config import PlotConfig
-from colors import hexcolor
+from .utils import Closure, LabelEntry
+from .config import PlotConfig
+from .colors import hexcolor
 
 FNB_STYLE = flat_nb.FNB_NO_X_BUTTON|flat_nb.FNB_SMART_TABS|flat_nb.FNB_NO_NAV_BUTTONS
 
@@ -80,29 +80,43 @@ class PlotConfigFrame(wx.Frame):
                                action = Closure(self.onText, argu='xlabel'))
 
         topsizer.Add(self.titl.label, (1, 0), (1, 1), labstyle, 5)
-        topsizer.Add(self.titl,       (1, 1), (1, 5), labstyle, 5)
+        topsizer.Add(self.titl,       (1, 1), (1, 4), labstyle, 5)
         topsizer.Add(self.ylab.label, (2, 0), (1, 1), labstyle, 5)
-        topsizer.Add(self.ylab,       (2, 1), (1, 5), labstyle, 5)
+        topsizer.Add(self.ylab,       (2, 1), (1, 4), labstyle, 5)
         topsizer.Add(self.y2lab.label,(3, 0), (1, 1), labstyle, 5)
-        topsizer.Add(self.y2lab,      (3, 1), (1, 5), labstyle, 5)
+        topsizer.Add(self.y2lab,      (3, 1), (1, 4), labstyle, 5)
         topsizer.Add(self.xlab.label, (4, 0), (1, 1), labstyle, 5)
-        topsizer.Add(self.xlab,       (4, 1), (1, 5), labstyle, 5)
+        topsizer.Add(self.xlab,       (4, 1), (1, 4), labstyle, 5)
 
 
-        tl2 = wx.StaticText(panel, -1, 'Text Size:', size=(-1, -1), style=labstyle)
+        tl2 = wx.StaticText(panel, -1, 'Label text size:', size=(-1, -1),
+                            style=labstyle)
         txt_size = wx.SpinCtrl(panel, -1, "", (-1, -1), (55, 30))
-        txt_size.SetRange(5, 30)
+        txt_size.SetRange(2, 20)
         txt_size.SetValue(self.conf.labelfont.get_size())
-        txt_size.Bind(wx.EVT_SPINCTRL, Closure(self.onText, argu='size'))
+        txt_size.Bind(wx.EVT_SPINCTRL, Closure(self.onText, argu='labelsize'))
 
-        topsizer.Add(tl2,        (1, 6), (1, 1), labstyle, 2)
-        topsizer.Add(txt_size,   (1, 7), (1, 1), labstyle, 2)
+        topsizer.Add(tl2,        (1, 5), (1, 1), labstyle, 2)
+        topsizer.Add(txt_size,   (1, 6), (1, 1), labstyle, 2)
 
+        tl2 = wx.StaticText(panel, -1, 'Legend text size:', size=(-1, -1),
+                            style=labstyle)
+        leg_size = wx.SpinCtrl(panel, -1, "", (-1, -1), (55, 30))
+        leg_size.SetRange(2, 20)
+        leg_size.SetValue(self.conf.legendfont.get_size())
+        leg_size.Bind(wx.EVT_SPINCTRL, Closure(self.onText, argu='legendsize'))
+
+        topsizer.Add(tl2,        (2, 5), (1, 1), labstyle, 2)
+        topsizer.Add(leg_size,   (2, 6), (1, 1), labstyle, 2)
 
         show_grid  = wx.CheckBox(panel,-1, 'Show Grid', (-1, -1), (-1, -1))
         show_grid.Bind(wx.EVT_CHECKBOX,self.onShowGrid)
         show_grid.SetValue(self.conf.show_grid)
 
+        show_box  = wx.CheckBox(panel,-1, 'Top/Right Axes', (-1, -1), (-1, -1))
+        show_box.Bind(wx.EVT_CHECKBOX, self.onShowBox)
+        show_box.SetValue(self.conf.axes_style == 'box')
+
         show_leg = wx.CheckBox(panel,-1, 'Show Legend', (-1, -1), (-1, -1))
         show_leg.Bind(wx.EVT_CHECKBOX,Closure(self.onShowLegend,argu='legend'))
         show_leg.SetValue(self.conf.show_legend)
@@ -111,9 +125,10 @@ class PlotConfigFrame(wx.Frame):
         show_lfr.Bind(wx.EVT_CHECKBOX,Closure(self.onShowLegend,argu='frame'))
         show_lfr.SetValue(self.conf.show_legend_frame)
 
-        topsizer.Add(show_grid, (2, 6), (1, 2), labstyle, 2)
-        topsizer.Add(show_leg,  (3, 6), (1, 2), labstyle, 2)
-        topsizer.Add(show_lfr,  (4, 6), (1, 2), labstyle, 2)
+        topsizer.Add(show_grid, (4, 5), (1, 1), labstyle, 2)
+        topsizer.Add(show_box,  (4, 6), (1, 1), labstyle, 2)
+        topsizer.Add(show_leg,  (3, 5), (1, 1), labstyle, 2)
+        topsizer.Add(show_lfr,  (3, 6), (1, 1), labstyle, 2)
 
 
         tcol = wx.StaticText(panel, -1, 'Colors',style=wx.ALIGN_LEFT|wx.ALIGN_CENTER_VERTICAL)
@@ -180,7 +195,7 @@ class PlotConfigFrame(wx.Frame):
 
         #bok = wx.Button(panel, -1, 'OK',    size=(-1,-1))
         #bok.Bind(wx.EVT_BUTTON,self.onExit)
-        
+
         #btnsizer = wx.BoxSizer(wx.HORIZONTAL)
         #btnsizer.Add(bok,0, wx.ALIGN_LEFT|wx.ALIGN_CENTER|wx.LEFT, 2)
 
@@ -270,7 +285,7 @@ class PlotConfigFrame(wx.Frame):
         # panel = wx.Panel(parent)
         panel = scrolled.ScrolledPanel(parent, size=(800, 200),
                                        style=wx.GROW|wx.TAB_TRAVERSAL, name='p1')
-        
+
         if font is None:
             font = wx.Font(13,wx.SWISS,wx.NORMAL,wx.NORMAL,False)
 
@@ -290,7 +305,7 @@ class PlotConfigFrame(wx.Frame):
             argu  = "trace %i" % i
             lin  = self.conf.traces[i]
             dlab = lin.label
-            dcol = lin.color
+            dcol = hexcolor(lin.color)
             dthk = lin.linewidth
             dmsz = lin.markersize
             dsty = lin.style
@@ -308,7 +323,7 @@ class PlotConfigFrame(wx.Frame):
             thk.SetValue(dthk)
             thk.Bind(wx.EVT_SPINCTRL, Closure(self.onThickness, argu=argu))
 
-            sty = wx.Choice(panel, -1, choices=self.conf.styles, size=(100,-1))
+            sty = wx.Choice(panel, -1, choices=self.conf.styles, size=(120,-1))
             sty.Bind(wx.EVT_CHOICE,Closure(self.onStyle,argu=argu))
             sty.SetStringSelection(dsty)
 
@@ -442,7 +457,7 @@ class PlotConfigFrame(wx.Frame):
         self.canvas.draw()
 
     def onText(self, event, argu=''):
-        if argu=='size':
+        if argu=='labelsize':
             size = event.GetInt()
             self.conf.labelfont.set_size(size)
             self.conf.titlefont.set_size(size+1)
@@ -451,6 +466,12 @@ class PlotConfigFrame(wx.Frame):
                     lab.set_fontsize(size)
             self.conf.relabel()
             return
+        if argu=='legendsize':
+            size = event.GetInt()
+            self.conf.legendfont.set_size(size)
+            # self.conf.relabel()
+            self.conf.draw_legend()
+            return
         if argu == 'title':
             wid = self.titl
         elif argu == 'ylabel':
@@ -480,7 +501,7 @@ class PlotConfigFrame(wx.Frame):
                 kws = {argu: s}
                 self.conf.relabel(**kws)
                 wid.SetBackgroundColour((255, 255, 255))
-            except ParseFatalException: # as from latex error!
+            except: # as from latex error!
                 wid.SetBackgroundColour((250, 250, 200))
         elif argu[:6] == 'trace ':
             try:
@@ -492,6 +513,11 @@ class PlotConfigFrame(wx.Frame):
     def onShowGrid(self,event):
         self.conf.enable_grid(show=event.IsChecked())
 
+    def onShowBox(self, event=None):
+        style='box'
+        if not event.IsChecked(): style='open'
+        self.conf.set_axes_style(style=style)
+
     def onShowLegend(self,event,argu=''):
         if (argu == 'legend'):
             self.conf.show_legend  = event.IsChecked()
