@@ -2,8 +2,8 @@
 """
  MPlot PlotFrame: a wx.Frame for 2D line plotting, using matplotlib
 """
-from plotpanel import PlotPanel
-from baseframe import BaseFrame
+from .plotpanel import PlotPanel
+from .baseframe import BaseFrame
 
 class PlotFrame(BaseFrame):
     """
@@ -20,6 +20,10 @@ class PlotFrame(BaseFrame):
                            **kws)
         self.BuildFrame()
 
+    def get_figure(self):
+        """return MPL plot figure"""
+        return self.panel.fig
+        
     def add_text(self, text, x, y, **kws):
         """add text to plot"""
         self.panel.add_text(text, x, y, **kws)
