@@ -3,7 +3,7 @@
 wxmplot PlotPanel: a wx.Panel for 2D line plotting, using matplotlib
 """
 import wx
-from numpy import nonzero
+from numpy import nonzero, where, ma
 import matplotlib
 from matplotlib.figure import Figure
 from matplotlib.ticker import FuncFormatter
@@ -11,11 +11,11 @@ from matplotlib.backends.backend_wxagg import FigureCanvasWxAgg as FigureCanvas
 
 from matplotlib.colors import colorConverter
 from matplotlib.collections import CircleCollection
-from matplotlib.nxutils import points_inside_poly
 
-from plotconfigframe import PlotConfigFrame
-from basepanel import BasePanel
-from config import PlotConfig
+from .plotconfigframe import PlotConfigFrame
+from .basepanel import BasePanel
+from .config import PlotConfig
+from .utils import inside_poly
 
 to_rgba = colorConverter.to_rgba
 class PlotPanel(BasePanel):
@@ -28,19 +28,22 @@ class PlotPanel(BasePanel):
     For more features, see PlotFrame, which embeds a PlotPanel
     and also provides, a Menu, StatusBar, and Printing support.
     """
-    def __init__(self, parent, size=(4.00, 2.48), dpi=150,
-                 axis_size=None, axisbg=None,
+    def __init__(self, parent, size=None, dpi=150,
+                 axissize=None, axisbg=None, fontsize=9,
                  trace_color_callback=None,
                  output_title='plot', **kws):
 
+        if size is None: size=(700, 450)
+
         self.trace_color_callback = trace_color_callback
         matplotlib.rc('axes', axisbelow=True)
         matplotlib.rc('lines', linewidth=2)
-        matplotlib.rc('xtick', labelsize=9, color='k')
-        matplotlib.rc('ytick', labelsize=9, color='k')
-        matplotlib.rc('legend', fontsize=9)
+        matplotlib.rc('xtick', labelsize=fontsize, color='k')
+        matplotlib.rc('ytick', labelsize=fontsize, color='k')
+        matplotlib.rc('legend', fontsize=fontsize)
         matplotlib.rc('grid',  linewidth=0.5, linestyle='-')
 
+
         BasePanel.__init__(self, parent,
                            output_title=output_title, **kws)
 
@@ -50,20 +53,19 @@ class PlotPanel(BasePanel):
         self.cursor_callback = None
         self.lasso_callback = None
         self.parent    = parent
-        self.figsize = size
+        self.figsize = (size[0]*1.0/dpi, size[1]*1.0/dpi)
         self.dpi     = dpi
 
-        if axis_size is None:  axis_size = [0.16, 0.16, 0.72, 0.75]
+        if axissize is None:  axissize = [0.16, 0.16, 0.72, 0.75]
         if axisbg is None:     axisbg='#FEFFFE'
         self.axisbg = axisbg
-        self.axis_size = axis_size
+        self.axissize = axissize
         self.BuildPanel()
         self.user_limits = {} # [None, None, None, None]
         self.data_range = {}
         self.zoom_lims = []
         self.axes_traces = {}
 
-
     def plot(self, xdata, ydata, side='left', title=None,
              xlabel=None, ylabel=None, y2label=None,
              use_dates=False, **kws):
@@ -85,7 +87,7 @@ class PlotPanel(BasePanel):
         if side == 'right':
             axes = self.get_right_axes()
         self.conf.ntrace  = 0
-        self.conf.cursor_mode = 'zoom'
+        self.cursor_mode = 'zoom'
         self.conf.plot_type = 'lineplot'
         self.user_limits[axes] = [None, None, None, None]
 
@@ -108,15 +110,23 @@ class PlotPanel(BasePanel):
               xmin=None, xmax=None, ymin=None, ymax=None,
               color=None, style=None, drawstyle=None,
               linewidth=2, marker=None, markersize=None,
-              autoscale=True, refresh=True, show_legend=None, **kws):
+              autoscale=True, refresh=True, show_legend=None,
+              legend_loc='ur', legend_on=True, delay_draw=False,
+              bgcolor=None, framecolor=None, gridcolor=None,
+              labelfontsize=None, legendfontsize=None,
+              fullbox=None, axes_style=None, zorder=None, **kws):
         """ basic plot method, overplotting any existing plot """
         axes = self.axes
         if side == 'right':
             axes = self.get_right_axes()
         # set y scale to log/linear
         yscale = 'linear'
-        if ylog_scale and min(ydata) > 0:
+        if ylog_scale:
             yscale = 'log'
+            # ydata = ma.masked_where(ydata<=0, 1.0*ydata)
+            # ymin = min(ydata[where(ydata>0)])
+            ydata[where(ydata<=0)] = None
+
         axes.set_yscale(yscale, basey=10)
         if linewidth is None:
             linewidth = 2
@@ -130,6 +140,7 @@ class PlotPanel(BasePanel):
         if title  is not None:
             self.set_title(title)
         if show_legend is not None:
+            self.conf.set_legend_location(legend_loc, legend_on)
             self.conf.show_legend = show_legend
 
         if grid is not None:
@@ -155,28 +166,34 @@ class PlotPanel(BasePanel):
 
         conf  = self.conf
         n    = conf.ntrace
+        if zorder is None:
+            zorder = 10*(n+1)
         if axes not in self.axes_traces:
             self.axes_traces[axes] = []
         self.axes_traces[axes].append(n)
-
         if conf.show_grid and axes == self.axes:
             # I'm sure there's a better way...
             for i in axes.get_xgridlines()+axes.get_ygridlines():
                 i.set_color(conf.grid_color)
+                i.set_zorder(0)
             axes.grid(True)
         else:
             axes.grid(False)
-
         if dy is None:
-            _lines = axes.plot(xdata, ydata, drawstyle=drawstyle)
+            _lines = axes.plot(xdata, ydata, drawstyle=drawstyle, zorder=zorder)
         else:
-            _lines = axes.errorbar(xdata, ydata, yerr=dy)
+            _lines = axes.errorbar(xdata, ydata, yerr=dy, zorder=zorder)
 
         if label is None:
             label = 'trace %i' % (conf.ntrace+1)
         conf.set_trace_label(label)
         conf.set_trace_datarange(datarange)
 
+        if bgcolor is not None:
+            axes.set_axis_bgcolor(bgcolor)
+        if framecolor is not None:
+            self.canvas.figure.set_facecolor(framecolor)
+
         if color:
             conf.set_trace_color(color)
         if style:
@@ -190,7 +207,18 @@ class PlotPanel(BasePanel):
         if drawstyle is not None:
             conf.set_trace_drawstyle(drawstyle)
 
-        conf.lines[n] = _lines
+        if gridcolor is not None:
+            conf.grid_color = gridcolor
+        if labelfontsize is not None:
+            conf.labelfont.set_size(labelfontsize)
+        if legendfontsize is not None:
+            conf.legendfont.set_size(legendfontsize)
+
+        if n < len(conf.lines):
+            conf.lines[n] = _lines
+        else:
+            conf._init_trace(n, 'black', solid)
+            conf.lines[n] = _lines
 
         # now set plot limits:
         self.set_viewlimits()
@@ -201,35 +229,52 @@ class PlotPanel(BasePanel):
         if self.conf.show_legend:
             conf.draw_legend()
 
-        self.canvas.draw()
-        self.canvas.Refresh()
+        # axes style ('box' or 'open')
+        conf.axes_style = 'box'
+        if fullbox is not None and not fullbox:
+            conf.axes_style = 'open'            
+        if axes_style in ('open', 'box', 'bottom'):
+            conf.axes_style = axes_style            
+        conf.set_axes_style()
+
+        if not delay_draw:
+            self.canvas.draw()
+            self.canvas.Refresh()
+
         conf.ntrace = conf.ntrace + 1
         return _lines
 
-    def add_text(self, text, x, y, side='left',
+    def add_text(self, text, x, y, side='left', size=None,
                  rotation=None, ha='left', va='center',
                  family=None, **kws):
         """add text at supplied x, y position"""
         axes = self.axes
         if side == 'right':
             axes = self.get_right_axes()
-        axes.text(x, y, text, ha=ha, va=va,
-                  rotation=rotation, family=family, **kws)
-        
+        dynamic_size = False
+        if size is None:
+            size = self.conf.legendfont.get_size()
+            dynamic_size = True
+        t = axes.text(x, y, text, ha=ha, va=va, size=size,
+                      rotation=rotation, family=family, **kws)
+        self.conf.added_texts.append((dynamic_size, t))
+        self.canvas.draw()
+
     def add_arrow(self, x1, y1, x2, y2,  side='left',
-                  shape='full', fg='black', width=0.01,
-                  head_width=0.1, overhang=0, **kws):
+                  shape='full', color='black',
+                  width=0.01, head_width=0.03, overhang=0, **kws):
         """add arrow supplied x, y position"""
         dx, dy = x2-x1, y2-y1
-        
+
         axes = self.axes
         if side == 'right':
             axes = self.get_right_axes()
         axes.arrow(x1, y1, dx, dy, shape=shape,
                    length_includes_head=True,
-                   fc=fg,
-                   width=width, head_width=0.1, # head_width,
-                   overhang=0.0, **kws)
+                   fc=color, edgecolor=color,
+                   width=width, head_width=head_width,
+                   overhang=overhang, **kws)
+        self.canvas.draw()
 
     def scatterplot(self, xdata, ydata, label=None, size=10,
                     color=None, edgecolor=None,
@@ -252,7 +297,7 @@ class PlotPanel(BasePanel):
             self.lasso_callback = callback
 
         self.conf.plot_type = 'scatter'
-        self.conf.cursor_mode = 'lasso'
+        self.cursor_mode = 'lasso'
         if color is not None:
             self.conf.scatter_normalcolor = color
         if edgecolor is not None:
@@ -285,65 +330,88 @@ class PlotPanel(BasePanel):
         if self.conf.show_grid:
             for i in axes.get_xgridlines()+axes.get_ygridlines():
                 i.set_color(self.conf.grid_color)
+                i.set_zorder(-100)
             axes.grid(True)
         else:
             axes.grid(False)
         self.set_viewlimits()
-
         self.canvas.draw()
 
     def lassoHandler(self, vertices):
         conf = self.conf
-        fcols = conf.scatter_coll.get_facecolors()
-        ecols = conf.scatter_coll.get_edgecolors()
-        mask = points_inside_poly(conf.scatter_data, vertices)
-        pts = nonzero(mask)[0]
-        self.conf.scatter_mask = mask
-        for i in range(len(conf.scatter_data)):
-            if i in pts:
-                ecols[i] = to_rgba(conf.scatter_selectedge)
-                fcols[i] = to_rgba(conf.scatter_selectcolor)
-                fcols[i][3] = 0.5
-            else:
-                fcols[i] = to_rgba(conf.scatter_normalcolor)
-                ecols[i] = to_rgba(conf.scatter_normaledge)
+
+        if self.conf.plot_type == 'scatter':
+            fcols = conf.scatter_coll.get_facecolors()
+            ecols = conf.scatter_coll.get_edgecolors()
+            sdat = conf.scatter_data
+            mask = inside_poly(vertices,sdat)
+            pts = nonzero(mask)[0]
+            self.conf.scatter_mask = mask
+            for i in range(len(sdat)):
+                if i in pts:
+                    ecols[i] = to_rgba(conf.scatter_selectedge)
+                    fcols[i] = to_rgba(conf.scatter_selectcolor)
+                    fcols[i][3] = 0.3
+                    ecols[i][3] = 0.8
+                else:
+                    fcols[i] = to_rgba(conf.scatter_normalcolor)
+                    ecols[i] = to_rgba(conf.scatter_normaledge)
+        else:
+            xdata = self.axes.lines[0].get_xdata()
+            ydata = self.axes.lines[0].get_ydata()
+            sdat = [(x, y) for x, y in zip(xdata, ydata)]
+            mask = inside_poly(vertices,sdat)
+            #print  len(xdata), sdat[:20]
+            # print mask
+            pts = nonzero(mask)[0]
+            #print 'Points selected = ', pts
 
         self.lasso = None
-        self.canvas.draw_idle()
+        self.canvas.draw()
+        # self.canvas.draw_idle()
         if (self.lasso_callback is not None and
             hasattr(self.lasso_callback , '__call__')):
-            self.lasso_callback(data = conf.scatter_coll.get_offsets(),
+            self.lasso_callback(data = sdat,
                                 selected = pts, mask=mask)
 
-    def set_xylims(self, limits, axes=None):
+    def set_xylims(self, limits, axes=None, side='left'):
         "set user-defined limits and apply them"
-        if axes not in self.user_limits:
+        if axes is None:
             axes = self.axes
+            if side == 'right':
+                axes = self.get_right_axes()
         self.user_limits[axes] = limits
         self.unzoom_all()
 
-
     def set_viewlimits(self, autoscale=False):
         """ update xy limits of a plot, as used with .update_line() """
-        for axes in self.fig.get_axes():
 
-            trace0 = self.axes_traces[axes][0]
+        trace0 = None
+        while trace0 is None:
+            for axes in self.fig.get_axes():
+                if (axes in self.axes_traces and
+                   len(self.axes_traces[axes]) > 0):
+                    trace0 = self.axes_traces[axes][0]
+                    break
+
+        for axes in self.fig.get_axes():
             datlim = self.conf.get_trace_datarange(trace=trace0)
-            for i in self.axes_traces[axes]:
-                l =  self.conf.get_trace_datarange(trace=i)
-                datlims= [min(datlim[0], l[0]), max(datlim[1], l[1]),
-                          min(datlim[2], l[2]), max(datlim[3], l[3])]
-           
+            if axes in self.axes_traces:
+                for i in self.axes_traces[axes]:
+                    l =  self.conf.get_trace_datarange(trace=i)
+                    datlim = [min(datlim[0], l[0]), max(datlim[1], l[1]),
+                              min(datlim[2], l[2]), max(datlim[3], l[3])]
+
             xmin, xmax = axes.get_xlim()
             ymin, ymax = axes.get_ylim()
             limits = [min(datlim[0], xmin),
                       max(datlim[1], xmax),
                       min(datlim[2], ymin),
                       max(datlim[3], ymax)]
-            
 
-            if (self.user_limits[axes] != 4*[None] or
-                len(self.zoom_lims) > 0):
+            if (axes in self.user_limits and
+                (self.user_limits[axes] != 4*[None] or
+                len(self.zoom_lims) > 0)):
 
                 for i, val in enumerate(self.user_limits[axes]):
                     if val is not None:
@@ -352,26 +420,9 @@ class PlotPanel(BasePanel):
                 if len(self.zoom_lims) > 0:
                     limits_set = True
                     xmin, xmax, ymin, ymax = self.zoom_lims[-1][axes]
-
                 axes.set_xlim((xmin, xmax), emit=True)
                 axes.set_ylim((ymin, ymax), emit=True)
 
-# 
-#             implicit_limits = ( len(self.zoom_lims) == 0 and
-#                                 self.user_limits[axes] == [None]*4)
-#                 
-#             # axes.set_xbound(axes.xaxis.get_major_locator().view_limits(xmin, xmax))
-#             # axes.set_ybound(axes.yaxis.get_major_locator().view_limits(ymin, ymax))
-# 
-#             if implicit_limits:
-#                 xmin, xmax = axes.get_xlim()
-#                 ymin, ymax = axes.get_ylim()
-# ;
-            #if len(self.zoom_lims) == 0:
-            #    self.zoom_lims.append({axes: [xmin, xmax, ymin, ymax]})
-
-
-                
     def get_viewlimits(self, axes=None):
         if axes is None: axes = self.axes
         xmin, xmax = axes.get_xlim()
@@ -394,7 +445,7 @@ class PlotPanel(BasePanel):
 
     def unzoom(self, event=None, set_bounds=True):
         """ zoom out 1 level, or to full data range """
-        if len(self.zoom_lims) >= 1:
+        if len(self.zoom_lims) > 1:
             self.zoom_lims.pop()
         self.set_viewlimits()
         self.canvas.draw()
@@ -427,7 +478,7 @@ class PlotPanel(BasePanel):
     def BuildPanel(self):
         """ builds basic GUI panel and popup menu"""
         self.fig   = Figure(self.figsize, dpi=self.dpi)
-        self.axes  = self.fig.add_axes(self.axis_size, axisbg=self.axisbg)
+        self.axes  = self.fig.add_axes(self.axissize, axisbg=self.axisbg)
 
         self.canvas = FigureCanvas(self, -1, self.fig)
 
@@ -469,7 +520,6 @@ class PlotPanel(BasePanel):
         #                                  max(dr[3], ydata.max())]
         # print 'Update ', trace, side, axes == self.get_right_axes(), dr
         # this defeats zooming, which gets ugly in this fast-mode anyway.
-        self.cursor_state = None
         if update_limits:
             self.set_viewlimits()
         if draw:
@@ -478,10 +528,12 @@ class PlotPanel(BasePanel):
     def draw(self):
         self.canvas.draw()
 
+    def get_figure(self):
+        return self.fig
     ####
     ## GUI events
     ####
-    def reportLeftDown(self, event=None):
+    def report_leftdown(self, event=None):
         if event is None:
             return
         ex, ey = event.x, event.y
@@ -491,8 +543,8 @@ class PlotPanel(BasePanel):
         except:
             x, y = event.xdata, event.ydata
 
-        msg = ("X,Y= %s, %s" % (self._xfmt, self._yfmt)) % (x, y)
-
+        if x is not None and y is not None:
+            msg = ("X,Y= %s, %s" % (self._xfmt, self._yfmt)) % (x, y)
         if len(self.fig.get_axes()) > 1:
             ax2 = self.fig.get_axes()[1]
             try:
@@ -505,4 +557,3 @@ class PlotPanel(BasePanel):
         if (self.cursor_callback is not None and
             hasattr(self.cursor_callback , '__call__')):
             self.cursor_callback(x=event.xdata, y=event.ydata)
-
